==> oceanbolt.sdk-0.1.9.tar.gz: oceanbolt.sdk-0.1.9/oceanbolt/com/fleetmanagement_v3/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .service import (
    RenameFleetRequest,
    CreateFleetRequest,
    DeleteFleetRequest,
    GetFleetRequest,
    ListVesselsRequest,
    ShareFleetRequest,
    DropVesselsRequest,
    BatchVesselsRequest,
    Fleets,
    Fleet,
    VesselParams,
    UpdateVesselParams,
    AddVesselRequest,
    UpdateVesselRequest,
    DeleteVesselRequest,
    Vessels,
    Vessel,
    GetFleetLiveMapRequest,
    GetFleetLiveMapResponse,
    EmptyParams,
    EmptyResponse,
)

__all__ = (
    'RenameFleetRequest',
    'CreateFleetRequest',
    'DeleteFleetRequest',
    'GetFleetRequest',
    'ListVesselsRequest',
    'ShareFleetRequest',
    'DropVesselsRequest',
    'BatchVesselsRequest',
    'Fleets',
    'Fleet',
    'VesselParams',
    'UpdateVesselParams',
    'AddVesselRequest',
    'UpdateVesselRequest',
    'DeleteVesselRequest',
    'Vessels',
    'Vessel',
    'GetFleetLiveMapRequest',
    'GetFleetLiveMapResponse',
    'EmptyParams',
    'EmptyResponse',
)

==> oceanbolt.sdk-0.2.7.tar.gz: oceanbolt.sdk-0.2.7/oceanbolt/com/fleetmanagement_v3/types/__init__.py <==
# -*- coding: utf-8 -*-

# Copyright 2020 Google LLC
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
#

from .service import (
    RenameFleetRequest,
    CreateFleetRequest,
    DeleteFleetRequest,
    GetFleetRequest,
    ListVesselsRequest,
    ListVesselsWithStatusRequest,
    ShareFleetRequest,
    DropVesselsRequest,
    BatchVesselsRequest,
    Fleets,
    Fleet,
    VesselParams,
    UpdateVesselParams,
    AddVesselRequest,
    UpdateVesselRequest,
    DeleteVesselRequest,
    Vessels,
    Vessel,
    VesselStatus,
    VesselStoppageEvent,
    GetFleetLiveMapRequest,
    GetFleetLiveMapResponse,
    EmptyParams,
    EmptyResponse,
)

__all__ = (
    'RenameFleetRequest',
    'CreateFleetRequest',
    'DeleteFleetRequest',
    'GetFleetRequest',
    'ListVesselsRequest',
    'ListVesselsWithStatusRequest',
    'ShareFleetRequest',
    'DropVesselsRequest',
    'BatchVesselsRequest',
    'Fleets',
    'Fleet',
    'VesselParams',
    'UpdateVesselParams',
    'AddVesselRequest',
    'UpdateVesselRequest',
    'DeleteVesselRequest',
    'Vessels',
    'Vessel',
    'VesselStatus',
    'VesselStoppageEvent',
    'GetFleetLiveMapRequest',
    'GetFleetLiveMapResponse',
    'EmptyParams',
    'EmptyResponse',
)
